@@ -132,7 +132,7 @@
     </message>
     <message>
         <location filename="../mainwindow.ui" line="613"/>
-        <location filename="../mainwindow.cpp" line="832"/>
+        <location filename="../mainwindow.cpp" line="834"/>
         <source>Block Driver</source>
         <translation>Estä ajuri</translation>
     </message>
@@ -393,137 +393,129 @@
         <translation>Moduuli estetty</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="762"/>
+        <location filename="../mainwindow.cpp" line="764"/>
         <source>Installation successful</source>
         <translation>Asennus onnistui</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="764"/>
+        <location filename="../mainwindow.cpp" line="766"/>
         <source>Error detected, could not compile ndiswrapper driver.</source>
         <translation>Virhe havaittu, ndiswrapper-ajuria ei voitu koota.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="767"/>
+        <location filename="../mainwindow.cpp" line="769"/>
         <source>Error detected, could not install ndiswrapper.</source>
         <translation>Virhe havaittu, ndiswrapper-ajuria ei voitu asentaa.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="779"/>
+        <location filename="../mainwindow.cpp" line="781"/>
         <source>Error encountered while removing Ndiswrapper</source>
         <translation>Virhe havaittu Ndiswrapper:in poistamisen aikana</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="829"/>
+        <location filename="../mainwindow.cpp" line="831"/>
         <source>Unblock Driver</source>
         <translation>Salli ajuri</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="861"/>
+        <location filename="../mainwindow.cpp" line="863"/>
         <source>enabled</source>
         <translation>käytössä</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="864"/>
+        <location filename="../mainwindow.cpp" line="866"/>
         <source>disabled</source>
         <translation>poistettu käytöstä</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="867"/>
+        <location filename="../mainwindow.cpp" line="869"/>
         <source>WiFi hardware switch is off</source>
         <translation>WiFi-laitteistovipu on asennossa pois päältä</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="874"/>
+        <location filename="../mainwindow.cpp" line="876"/>
         <source>Locate the Windows driver you want to add</source>
         <translation>Paikallista Windows-ajurit jotka haluat lisätä</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="875"/>
+        <location filename="../mainwindow.cpp" line="877"/>
         <source>Windows installation information file (*.inf)</source>
         <translation>Windows-asennuksen tietopohjainen tiedosto (*.inf)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="906"/>
-        <source>*.sys file no</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="918"/>
-        <source>sys file refeot found</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
+        <location filename="../mainwindow.cpp" line="908"/>
         <source>*.sys file not found</source>
-        <translation type="vanished">*.sys -tiedostoa ei löytynyt</translation>
+        <translation>*.sys -tiedostoa ei löytynyt</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="907"/>
+        <location filename="../mainwindow.cpp" line="909"/>
         <source>The *.sys files must be in the same location as the *.inf file. %1 cannot be found</source>
         <translation>*.sys tiedostot pitää olla samassa kohteessa kuin *.inf tiedosto. %1 ei löydetty</translation>
     </message>
     <message>
+        <location filename="../mainwindow.cpp" line="920"/>
         <source>sys file reference not found</source>
-        <translation type="vanished">sys-tiedostoviitettä ei löytynyt</translation>
+        <translation>sys-tiedostoviitettä ei löytynyt</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="919"/>
+        <location filename="../mainwindow.cpp" line="921"/>
         <source>The sys file for the given driver cannot be determined after parsing the inf file</source>
         <translation>Sys tiedostoa annetulle ajurille ei voida ennakoida inf-tiedoston jäsentämisen jälkeen</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="936"/>
+        <location filename="../mainwindow.cpp" line="938"/>
         <source>Ndiswrapper driver removed.</source>
         <translation>Ndiswrapper-ajuri poistettu.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="944"/>
+        <location filename="../mainwindow.cpp" line="946"/>
         <source>%1 Help</source>
         <translation>%1 Apuopas</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="956"/>
+        <location filename="../mainwindow.cpp" line="958"/>
         <source>Could not unlock devices.
 WiFi device(s) might already be unlocked.</source>
         <translation>Laitteita ei onnistuttu avaamaan lukituksesta.
 WiFi-laite (tai laitteet) ovat mahdollisesti jo avattu lukituksesta.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="958"/>
+        <location filename="../mainwindow.cpp" line="960"/>
         <source>WiFi devices unlocked.</source>
         <translation>Wifi-laitteiden lukitus purettu.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="973"/>
+        <location filename="../mainwindow.cpp" line="975"/>
         <source>About %1</source>
         <translation>%1 lisätietoja</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="974"/>
+        <location filename="../mainwindow.cpp" line="976"/>
         <source>Version: </source>
         <translation>Versio: </translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="976"/>
+        <location filename="../mainwindow.cpp" line="978"/>
         <source>Program for troubleshooting and configuring network for MX Linux</source>
         <translation>Ohjelma ongelmanratkaisuun ja verkon asetuksiin MX Linux:issa</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="978"/>
+        <location filename="../mainwindow.cpp" line="980"/>
         <source>Copyright (c) MEPIS LLC and MX Linux</source>
         <translation>Tekijänoikeus (c) MEPIS LLC ja MX Linux</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="979"/>
+        <location filename="../mainwindow.cpp" line="981"/>
         <source>%1 License</source>
         <translation>%1 lupa</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1005"/>
+        <location filename="../mainwindow.cpp" line="1007"/>
         <source>Driver loaded successfully</source>
         <translation>Ajuri ladattu onnistuneesti</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1020"/>
+        <location filename="../mainwindow.cpp" line="1022"/>
         <source>Driver unloaded successfully</source>
         <translation>Ajuri onnistuneesti purettu.</translation>
     </message>
